DayContainer class

Inheritance

Constructors

DayContainer({required int index, required BoxDecoration decoration, required VoidCallback onPress, required Widget child, required double size, required dynamic callback, required int r_index, required int c_index, required int day, required dynamic selected, required List<int> nsd})

Properties

c_index int
final
callback ↔ dynamic
getter/setter pair
child Widget
final
day int
getter/setter pair
decoration BoxDecoration
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
nsd List<int>
getter/setter pair
onPress VoidCallback
final
r_index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ dynamic
getter/setter pair
size double
getter/setter pair

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DayContainer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited