Year<T> class

Constructors

Year({required int year, required List<Month<T>> months})

Properties

hashCode int
The hash code for this object.
no setterinherited
months List<Month<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
final

Methods

getAllData() List<T>
getMonthByName(String monthName) Month<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited